###########
LSST Metald
###########

**Metald (meta linked data; pronounced "metal d") is a Python library for gathering metadata about LSST's software and documentation projects and synthesizing it into JSON-LD (linked data) resources.**

This project is related to LSST DocHub, an experimental project to gather LSST information artifacts from across the web, and make them discoverable through a single API.
DocHub adapters can use this library to create LSST DocHub JSON-LD resources.

Metald is developed by **LSST**, the Large Synoptic Survey Telescope.
Learn more at `www.lsst.org <https://www.lsst.org>`_.

License
=======

Metald is MIT licensed. See `LICENSE <./LICENSE>`_.
